---
title: Pages Router
description: Before Next.js 13, the Pages Router was the main way to create routes in Next.js with an intuitive file-system router.
---

> You're viewing the documentation for the Pages Router. See the [App Router](/docs/app) documentation for the latest features.

The **Pages Router** uses an intuitive file-system router to map each file to a route.

Before Next.js 13, the Pages Router was the main way to create routes in Next.js. It's still supported in newer versions of Next.js, but we recommend migrating to the new [App Router](/docs/app) to leverage React's latest features.
